/*
 * This SQL script is specific to HSQLDB
 */
drop table if exists lds;
drop table if exists objecttype;
drop table if exists datasource;
drop table if exists mapping;
drop table if exists mappingtype;

drop table if exists object;
drop table if exists attribute;
drop table if exists attribute_temp;
drop table if exists attribute_fused;
drop table if exists mapresult;
drop table if exists mapresult_temp;
drop table if exists queryresult;
drop table if exists queryresult_temp;

drop table if exists var_object;
drop table if exists var_object_store;
drop table if exists var_mapresult;
drop table if exists var_mapresult_store;
drop table if exists var_aggregatedobject;
drop table if exists var_aggregatedobject_store;
drop table if exists var_aggregatedmappingresult;
drop table if exists var_aggregatedmappingresult_store;
drop table if exists var_string;
drop table if exists var_integer;
drop table if exists var_float;

drop table if exists op_object;
drop table if exists op_mapresult;
drop table if exists op_aggregatedobject;
drop table if exists op_aggregatedmappingresult;

drop table if exists op_query;
drop table if exists op_query1;
drop table if exists op_query2;

drop table if exists tree_tree;
drop table if exists tree_nodeaggregatedobject;
drop table if exists tree_nodeaggregatedobject_store;
drop table if exists tree_nodemappingtype;
drop table if exists tree_edge_aomt;
drop table if exists tree_edge_mtao;

drop index indexobjectid if exists;
drop index indexao if exists;
drop index ind_opmr_inputobjectid if exists;
drop index ind_opmr_outputobjectid if exists;
drop index indexqry if exists;

CREATE TABLE attribute (
  Attr_ID int IDENTITY PRIMARY KEY NOT NULL,
  Attr_ObjectID_FK int default '0' NOT NULL,
  Attr_Name varchar(1000) default '' NOT NULL,
  Attr_Value varchar(1000) default '' NOT NULL
);

CREATE INDEX indexobjectid ON attribute (Attr_ObjectID_FK);

CREATE TABLE attribute_temp (
  Attr_ObjectID_FK int default '0' NOT NULL,
  Attr_Name varchar(1000) default '' NOT NULL,
  Attr_Value varchar(1000) default '' NOT NULL,
  Attr_Obj_ldsID_FK int default '0' NOT NULL,
  Attr_Obj_AttributeIDValue varchar(990) default ''
);

CREATE TABLE attribute_fused (
  attr_id int IDENTITY PRIMARY KEY NOT NULL,
  attr_varid_fk int default '0' NOT NULL,
  attr_sameid_fk int default '0' NOT NULL,
  attr_name varchar(1000) default '' NOT NULL,
  attr_value varchar(1000) default '' NOT NULL
);

CREATE TABLE datasource (
  ds_id int IDENTITY PRIMARY KEY NOT NULL,
  ds_name varchar(100) DEFAULT '' NOT NULL
);

CREATE TABLE lds (
  lds_id int IDENTITY PRIMARY KEY NOT NULL,
  lds_attributename varchar(100) default '' NOT NULL,
  lds_objecttypeid_fk int default '0' NOT NULL,
  lds_datasourceid_fk int default '0' NOT NULL
);

CREATE TABLE mapping (
  map_id int IDENTITY PRIMARY KEY NOT NULL,
  map_mappingtypeid_fk int default '0' NOT NULL,
  map_name varchar(100) default '' NOT NULL,
  map_inputldsid_fk int default '0' NOT NULL,
  map_outputldsid_fk int default '0' NOT NULL
);

CREATE TABLE mappingtype (
  mt_id int IDENTITY PRIMARY KEY NOT NULL,
  mt_inputobjecttypeid_fk int default '0' NOT NULL,
  mt_outputobjecttypeid_fk int default '0' NOT NULL,
  mt_issamemapping boolean default false NOT NULL,
  mt_name varchar(100) default '' NOT NULL
);

CREATE TABLE mapresult (
  MR_ID int IDENTITY PRIMARY KEY NOT NULL,
  MR_MappingID_FK int default '0' NOT NULL,
  MR_Confidence float default '1',
  MR_LeftObjectID_FK int default '0' NOT NULL,
  MR_RightObjectID_FK int default NULL,
  mr_param varchar(255) default NULL,
  UNIQUE (MR_MappingID_FK,MR_LeftObjectID_FK,MR_RightObjectID_FK,mr_param)
);

CREATE TABLE mapresult_temp (
  mr_id int IDENTITY PRIMARY KEY NOT NULL,
  mr_mappingid_fk varchar(100) default '',
  mr_confidence float default '1',
  mr_rightldsid_fk int default '0' NOT NULL,
  mr_rightattributeidvalue varchar(990) default '',
  mr_leftldsid_fk int default '0' NOT NULL,
  mr_leftattributeIDValue varchar(990) default NULL,
  mr_param varchar(255) default NULL
);

CREATE TABLE object (
  Obj_ID int IDENTITY PRIMARY KEY NOT NULL,
  Obj_LDSID_FK int default '0' NOT NULL,
  Obj_SameObjectId_FK int default NULL,
  Obj_AttributeIDValue varchar(990) default '',
  UNIQUE (Obj_LDSID_FK,Obj_AttributeIDValue)
);

CREATE TABLE objecttype (
  ot_id int IDENTITY PRIMARY KEY NOT NULL,
  ot_name varchar(100) default '' NOT NULL
);

CREATE TABLE op_aggregatedmappingresult (
  opamr_id int IDENTITY PRIMARY KEY NOT NULL,
  opamr_inputobjectid_fk int default '0' NOT NULL,
  opamr_outputobjectid_fk int default '0' NOT NULL
);

CREATE TABLE op_aggregatedobject (
  opao_id int IDENTITY PRIMARY KEY NOT NULL,
  opao_objectid_fk int default '0' NOT NULL,
  opao_samegroup int default '0' NOT NULL,
  opao_ldsid_fk int default '0' NOT NULL,
  opao_flag int default '0' NOT NULL
);

CREATE INDEX indexao ON op_aggregatedobject (opao_samegroup);

CREATE TABLE op_mapresult (
  opmr_id int IDENTITY PRIMARY KEY NOT NULL,
  opmr_inputobjectid_fk int default '0' NOT NULL,
  opmr_inputsameid_fk int default '0',
  opmr_inputldsid_fk int default '0',
  opmr_inputconfidence float default '0' NOT NULL,
  opmr_outputobjectid_fk int default '0',
  opmr_outputsameid_fk int default '0',
  opmr_outputldsid_fk int default '0',
  opmr_outputconfidence float default '0',
  opmr_confidence float default '1',
  opmr_occurence int default '0',
  opmr_mapresultid_fk int default '0',
  opmr_jd00 float default '0',
  opmr_jd01 float default '0',
  opmr_jd10 float default '0',
  opmr_jd11 float default '0',
  opmr_flag int default '0' NOT NULL
);

CREATE INDEX ind_opmr_inputobjectid ON op_mapresult (opmr_inputobjectid_fk);

CREATE INDEX ind_opmr_outputobjectid ON op_mapresult (opmr_outputobjectid_fk);

CREATE TABLE op_object (
  opobj_id int IDENTITY PRIMARY KEY NOT NULL,
  opobj_objectid_fk int default '0' NOT NULL,
  opobj_confidence float default '0',
  opobj_flag int default '0' NOT NULL
);

CREATE TABLE op_query (
  op_samegroup int default NULL,
  DBLP_series varchar(100) default NULL,
  DBLP_title varchar(100) default NULL,
  DBLP_xml_key varchar(100) default NULL,
  DBLP_year varchar(100) default NULL
);

CREATE INDEX indexqry ON op_query (op_samegroup);

CREATE TABLE op_query1 (
  op_samegroup int default NULL,
  DBLP_key varchar(100) default NULL,
  DBLP_name varchar(100) default NULL,
  DBLP_NoOfChildren varchar(100) default NULL,
  DBLP_series varchar(100) default NULL,
  DBLP_type varchar(100) default NULL,
  DBLP_year varchar(100) default NULL
);

CREATE TABLE op_query2 (
  op_samegroup int default NULL,
  DBLP_author varchar(100) default NULL
);

CREATE TABLE queryresult (
  QR_ID int IDENTITY PRIMARY KEY NOT NULL,
  QR_MappingID_FK int default '0' NOT NULL,
  QR_Confidence float default '0',
  QR_Query varchar(1000) default '' NOT NULL,
  QR_ObjectID_FK int default '0' NOT NULL
);

CREATE TABLE queryresult_temp (
  QR_MappingID_FK int default '0' NOT NULL,
  QR_Confidence float default '0',
  QR_Query varchar(1000) default '' NOT NULL,
  QR_RightLDSID_FK int default '0' NOT NULL,
  QR_RightAttributeIDValue varchar(990) default '' NOT NULL
);

CREATE TABLE tree_edge_aomt (
  edgeam_id int IDENTITY PRIMARY KEY NOT NULL,
  edgeam_treeid_fk int default '0' NOT NULL,
  edgeam_nodeaoid_fk int default '0' NOT NULL,
  edgeam_nodemtid_fk int default '0' NOT NULL
);

CREATE TABLE tree_edge_mtao (
  edgema_id int IDENTITY PRIMARY KEY NOT NULL,
  edgema_treeid_fk int default '0' NOT NULL,
  edgema_nodemtid_fk int default '0',
  edgema_nodeaoid_fk int default '0' NOT NULL
);

CREATE TABLE tree_nodeaggregatedobject (
  nao_id int IDENTITY PRIMARY KEY NOT NULL,
  nao_treeid_fk int default '0' NOT NULL,
  nao_objecttypeid_fk int default '0' NOT NULL
);

CREATE TABLE tree_nodeaggregatedobject_store (
  naostore_id int IDENTITY PRIMARY KEY NOT NULL,
  naostore_treeid_fk int default '0' NOT NULL,
  naostore_nodeaoid_fk int default '0' NOT NULL,
  naostore_samegroup int default '0' NOT NULL,
  naostore_objectid_fk int default '0' NOT NULL
);

CREATE TABLE tree_nodemappingtype (
  nmt_id int IDENTITY PRIMARY KEY NOT NULL,
  nmt_treeid_fk int default '0' NOT NULL,
  nmt_mappingtypeid_fk int default '0' NOT NULL
);

CREATE TABLE tree_tree (
  tree_id int IDENTITY PRIMARY KEY NOT NULL,
  tree_name varchar(100) default '' NOT NULL
);

CREATE TABLE var_aggregatedmappingresult (
  vamr_id int IDENTITY PRIMARY KEY NOT NULL,
  vamr_name varchar(100) default '' NOT NULL,
  vamr_inputobjects_varid_fk int default '0' NOT NULL,
  vamr_outputobjects_varid_fk int default '0' NOT NULL,
  UNIQUE (vamr_name)
);

CREATE TABLE var_aggregatedmappingresult_store (
  vamrstore_id int IDENTITY PRIMARY KEY NOT NULL,
  vamrstore_varid_fk int default 0 NOT NULL,
  vamrstore_confidence float default '1' NOT NULL,
  vamrstore_occurence int default '1' NOT NULL,
  vamrstore_inputsamegroup int default '0' NOT NULL,
  vamrstore_outputsamegroup int default '0' NOT NULL
);

CREATE TABLE var_aggregatedobject (
  vao_id int IDENTITY PRIMARY KEY NOT NULL,
  vao_objecttypeid_fk int default '0' NOT NULL,
  vao_name varchar(100) default '' NOT NULL,
  UNIQUE (vao_name)
);

CREATE TABLE var_aggregatedobject_store (
  vaostore_id int IDENTITY PRIMARY KEY NOT NULL,
  vaostore_varid_fk int default '0' NOT NULL,
  vaostore_objectid_fk int default '0' NOT NULL,
  vaostore_ldsid_fk int default '0' NOT NULL,
  vaostore_sort int default '0',
  vaostore_samegroup int default '0' NOT NULL
);

CREATE TABLE var_float (
  vfloat_id int IDENTITY PRIMARY KEY NOT NULL,
  vfloat_name varchar(100) default '' NOT NULL,
  vfloat_value float default '0' NOT NULL
);

CREATE TABLE var_integer (
  vint_id int IDENTITY PRIMARY KEY NOT NULL,
  vint_name varchar(100) default '' NOT NULL,
  vint_value int default '0' NOT NULL
);

CREATE TABLE var_mapresult (
  vmr_id int IDENTITY PRIMARY KEY NOT NULL,
  vmr_inputldsid_fk int default '0' NOT NULL,
  vmr_outputldsid_fk int default '0' NOT NULL,
  vmr_name varchar(100) default '' NOT NULL,
  UNIQUE (vmr_name)
);

CREATE TABLE var_mapresult_store (
  vmrstore_id int IDENTITY PRIMARY KEY NOT NULL,
  vmrstore_varid_fk int default '0' NOT NULL,
  vmrstore_confidence float default '1',
  vmrstore_occurence int default '0',
  vmrstore_inputobjectid_fk int default '0' NOT NULL,
  vmrstore_inputobject_confidence float default '1',
  vmrstore_outputobject_confidence float default '1',
  vmrstore_outputobjectid_fk int default '0' NOT NULL
);

CREATE TABLE var_object (
  vobj_id int IDENTITY PRIMARY KEY NOT NULL,
  vobj_ldsid_fk int default '0' NOT NULL,
  vobj_name varchar(100) default '' NOT NULL,
  UNIQUE (vobj_name)
);

CREATE TABLE var_object_store (
  vobjstore_id int IDENTITY PRIMARY KEY NOT NULL,
  vobjstore_varid_fk int default '0' NOT NULL,
  vobjstore_confidence float default '0',
  vobjstore_sort int default '0' NOT NULL,
  vobjstore_objectid_fk int default '0' NOT NULL
);

CREATE TABLE var_string (
  vstr_id int IDENTITY PRIMARY KEY NOT NULL,
  vstr_name varchar(100) default '' NOT NULL,
  vstr_value varchar(3000) default '' NOT NULL
)