/*==============================================================*/
/* Database name:  REPOSITORY                                   */
/* DBMS name:      MySQL 3.23                                   */
/* Created on:     12.07.2005 15:05:16                          */
/*==============================================================*/


/*==============================================================*/
/* Table: rep_obj_type                                          */
/*==============================================================*/
create table if not exists rep_obj_type
(
   obj_type_id                    int                            not null auto_increment,
   isa_obj_type_id                int,
   obj_type_name                  varchar(50)                    not null,
   primary key (obj_type_id)
) ENGINE=MyISAM DEFAULT CHARSET=latin1; 

/*==============================================================*/
/* Index: idx_rep_object_type                                   */
/*==============================================================*/
create index idx_rep_object_type on rep_obj_type
(
   obj_type_id,
   obj_type_name
);

/*==============================================================*/
/* Table: rep_pds                                               */
/*==============================================================*/
create table if not exists rep_pds
(
   pds_id                         int                            not null auto_increment,
   source_name                    varchar(50)                    not null,
   primary key (pds_id)
) ENGINE=MyISAM DEFAULT CHARSET=latin1; 

/*==============================================================*/
/* Index: idx_rep_pds                                           */
/*==============================================================*/
create index idx_rep_pds on rep_pds
(
   pds_id,
   source_name
);

/*==============================================================*/
/* Table: rep_lds                                               */
/*==============================================================*/
create table if not exists rep_lds
(
   lds_id                         int                            not null auto_increment,
   obj_type_id                    int                            not null,
   pds_id                         int                            not null,
   display                        varchar(100)                   default null,
   primary key (lds_id)
) ENGINE=MyISAM DEFAULT CHARSET=latin1; 

/*==============================================================*/
/* Index: idx_rep_lds                                           */
/*==============================================================*/
create index idx_rep_lds on rep_lds
(
   lds_id,
   obj_type_id,
   pds_id
);

/*==============================================================*/
/* Table: rep_map_type                                          */
/*==============================================================*/
create table if not exists rep_map_type
(
   map_type_id                    int                            not null auto_increment,
   input_obj_type_id              int                            not null,
   output_obj_type_id             int                            not null,
   map_type_name                  varchar(50)                    not null,
   is_same_map                    int                            not null default 0,
   primary key (map_type_id)
) ENGINE=MyISAM DEFAULT CHARSET=latin1; 

/*==============================================================*/
/* Index: idx_rep_map_type                                      */
/*==============================================================*/
create index idx_rep_map_type on rep_map_type
(
   map_type_id,
   input_obj_type_id,
   output_obj_type_id,
   map_type_name
); 

/*==============================================================*/
/* Table: rep_mapping                                           */
/*==============================================================*/
create table if not exists rep_mapping
(
   map_id                         int                            not null auto_increment,
   map_type_id                    int                            not null,
   input_lds_id                   int                            not null,
   output_lds_id                  int                            not null,
   is_only_id                     int                            not null default 0,
   is_id_output                   int                            not null default 0,
   map_name                       varchar(50)                    not null,
   map_class                      varchar(50)                    not null,
   exec_type                      varchar(50)                    not null,
   is_bulk_map                    int                            not null default 0,
   is_match_all                   int                            not null default 0,
   map_call                       varchar(5000)                  not null,
   safe_point_size                int                            not null default -1,
   primary key (map_id)
) ENGINE=MyISAM DEFAULT CHARSET=latin1; 

/*==============================================================*/
/* Index: idx_rep_mapping                                       */
/*==============================================================*/
create index idx_rep_mapping on rep_mapping
(
   map_id,
   map_type_id,
   input_lds_id,
   output_lds_id,
   map_name
);

/*==============================================================*/
/* Table: rep_attribute                                         */
/*==============================================================*/
create table if not exists rep_attribute
(
   attr_id                        int                            not null auto_increment,
   lds_id                         int                            not null,
   attr_name                      varchar(50)                    not null,
   is_key                         int                            not null default 0,
   is_mand                        int                            not null default 0,
   primary key (attr_id)
) ENGINE=MyISAM DEFAULT CHARSET=latin1; 

/*==============================================================*/
/* Index: idx_rep_attribute                                     */
/*==============================================================*/
create index idx_rep_attribute on rep_attribute
(
   attr_id,
   lds_id,
   attr_name
);

/*==============================================================*/
/* Table: rep_correspondence                                    */
/*==============================================================*/
create table if not exists rep_correspondence
(
   correspondence_id              int                            not null auto_increment,
   lds_1_id                       int                            not null,
   lds_2_id                       int                            not null,
   expr_1_id                      int,
   expr_2_id                      int,
   attr_1_id                      int,
   attr_2_id                      int,
   is_direct                      int                            default 0,
   is_equal                       int                            default 0,
   evidence                       float                          default 1,
   primary key (correspondence_id)
) ENGINE=MyISAM DEFAULT CHARSET=latin1; 

/*==============================================================*/
/* Index: idx_rep_correspondence                                */
/*==============================================================*/
create index idx_rep_correspondence on rep_correspondence
(
   correspondence_id,
   lds_1_id,
   lds_2_id
);

/*==============================================================*/
/* Table: rep_expression                                        */
/*==============================================================*/
create table if not exists rep_expression
(
   expr_id                      int                              not null auto_increment,
   expression                   varchar(100)                     not null,
   primary key (expr_id)
) ENGINE=MyISAM DEFAULT CHARSET=latin1; 

/*==============================================================*/
/* Index: idx_rep_expression                                    */
/*==============================================================*/
create index idx_rep_expression on rep_expression
(
   expr_id,
   expression
);

/*==============================================================*/
/* Table: rep_expr_attr_rel                                     */
/*==============================================================*/
create table if not exists rep_expr_attr_rel
(
   expr_id                      int                              not null,
   attr_id                      int                              not null,
   primary key (expr_id,attr_id)
) ENGINE=MyISAM DEFAULT CHARSET=latin1; 

/*==============================================================*/
/* Index: idx_rep_expr_attr_rel                                 */
/*==============================================================*/
create index idx_rep_expr_attr_rel on rep_expr_attr_rel
(
   expr_id,
   attr_id
);

/*==============================================================*/
/* Table: rep_map_path                                          */
/*==============================================================*/
create table if not exists rep_map_path
(
   map_path_id                    int                            not null,
   start_lds_id                   int                            not null,
   end_lds_id                     int                            not null,
   map_id                         int                            not null,
   is_same_path                   int                            not null,
   map_pos                        int                            not null,
   primary key (map_path_id, map_pos)
) ENGINE=MyISAM DEFAULT CHARSET=latin1; 

/*==============================================================*/
/* Index: idx_rep_mapping_path                                  */
/*==============================================================*/
create index idx_rep_mapping_path on rep_map_path
(
   start_lds_id,
   end_lds_id,
   map_id
);

/*==============================================================*/
/* Table: rep_smm                                               */
/*==============================================================*/
create table if not exists rep_smm
(
   smm_id                         int                            not null auto_increment,
   smm_name                       varchar(100)                   not null,
   is_loaded                      int                            not null default 0,
   primary key (smm_id)
) ENGINE=MyISAM DEFAULT CHARSET=latin1; 

/*==============================================================*/
/* Index: idx_rep_smm                                           */
/*==============================================================*/
create index idx_rep_smm on rep_smm
(
   smm_id,
   smm_name
);

/*==============================================================*/
/* Table: rep_smm_map_rel                                       */
/*==============================================================*/
create table if not exists rep_smm_map_rel
(
   smm_id                         int                            not null,
   map_id                         int                            not null,
   primary key (smm_id,map_id)
) ENGINE=MyISAM DEFAULT CHARSET=latin1; 

/*==============================================================*/
/* Index: idx_rep_smm_map_rel                                   */
/*==============================================================*/
create index idx_rep_smm_map_rel on rep_smm_map_rel
(
   smm_id,
   map_id
);